<?php

namespace Drupal\podcast_publisher\Plugin\media\Source;

use Drupal\media\MediaInterface;
use Drupal\media\Plugin\media\Source\AudioFile;

/**
 * Media source wrapping around an audio file.
 *
 * @see \Drupal\file\FileInterface
 *
 * @MediaSource(
 *   id = "podcast_episode",
 *   label = @Translation("Podcast Episode"),
 *   description = @Translation("Use audio files for reusable media."),
 *   allowed_field_types = {"file"},
 *   default_thumbnail_filename = "audio.png"
 * )
 */
class PodcastEpisode extends AudioFile {

  /**
   * {@inheritdoc}
   */
  public function getMetadata(MediaInterface $media, $attribute_name) {
    /** @var \Drupal\file\FileInterface $file */
    $file = $media->get($this->configuration['source_field'])->entity;
    // If the source field is not required, it may be empty.
    if (!$file) {
      return parent::getMetadata($media, $attribute_name);
    }
    switch ($attribute_name) {
      case static::METADATA_ATTRIBUTE_NAME:
      case 'default_name':
        return $file->getFilename();

      case static::METADATA_ATTRIBUTE_MIME:
        return $file->getMimeType();

      case static::METADATA_ATTRIBUTE_SIZE:
        return $file->getSize();

      case 'thumbnail_uri':
        return $this->getThumbnailFromImage($media) ?: parent::getMetadata($media, $attribute_name);

      default:
        return parent::getMetadata($media, $attribute_name);
    }
  }

  /**
   * Gets thumbnail uri.
   *
   * @param \Drupal\media\Entity\Media $media
   *   The podcast episode media entity.
   *
   * @return string|null
   *   The uri to the thumbnail image.
   */
  protected function getThumbnailFromImage($media) {
    /** @var \Drupal\file\Entity\File $image_file */
    if ($image_file = $media->get('field_episode_image')->entity) {
      return $image_file->getFileUri();
    }
    return NULL;
  }



}
